aboutsummaryrefslogtreecommitdiffstats
path: root/net/tipc/subscr.h
diff options
context:
space:
mode:
authorJon Maloy <jon.maloy@ericsson.com>2018-02-15 10:40:48 +0100
committerDavid S. Miller <davem@davemloft.net>2018-02-16 15:26:34 -0500
commitda0a75e86ae230f92743c073843d3ea35bd061af (patch)
tree0d9399dc7925997a99590a8c65788768cf5aa588 /net/tipc/subscr.h
parenttipc: collapse subscription creation functions (diff)
downloadlinux-dev-da0a75e86ae230f92743c073843d3ea35bd061af.tar.xz
linux-dev-da0a75e86ae230f92743c073843d3ea35bd061af.zip
tipc: some prefix changes
Since we now have removed struct tipc_subscriber from the code, and only struct tipc_subscription remains, there is no longer need for long and awkward prefixes to distinguish between their pertaining functions. We now change all tipc_subscrp_* prefixes to tipc_sub_*. This is a purely cosmetic change. Acked-by: Ying Xue <ying.xue@windriver.com> Signed-off-by: Jon Maloy <jon.maloy@ericsson.com> Signed-off-by: David S. Miller <davem@davemloft.net>
Diffstat (limited to '')
-rw-r--r--net/tipc/subscr.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/net/tipc/subscr.h b/net/tipc/subscr.h
index 2d35f1046754..720932896ba6 100644
--- a/net/tipc/subscr.h
+++ b/net/tipc/subscr.h
@@ -51,7 +51,7 @@ struct tipc_conn;
* @seq: name sequence associated with subscription
* @timer: timer governing subscription duration (optional)
* @nameseq_list: adjacent subscriptions in name sequence's subscription list
* @subscrp_list: adjacent subscriptions in subscriber's subscription list
* @evt: template for events generated by subscription
*/
struct tipc_subscription {
@@ -59,7 +59,7 @@ struct tipc_subscription {
struct tipc_server *server;
struct timer_list timer;
struct list_head nameseq_list;
- struct list_head subscrp_list;
+ struct list_head sub_list;
struct tipc_event evt;
int conid;
bool inactive;
@@ -71,17 +71,17 @@ struct tipc_subscription *tipc_sub_subscribe(struct tipc_server *srv,
int conid);
void tipc_sub_unsubscribe(struct tipc_subscription *sub);
-int tipc_subscrp_check_overlap(struct tipc_name_seq *seq, u32 found_lower,
- u32 found_upper);
-void tipc_subscrp_report_overlap(struct tipc_subscription *sub,
- u32 found_lower, u32 found_upper,
- u32 event, u32 port, u32 node,
- u32 scope, int must);
+int tipc_sub_check_overlap(struct tipc_name_seq *seq, u32 found_lower,
+ u32 found_upper);
+void tipc_sub_report_overlap(struct tipc_subscription *sub,
+ u32 found_lower, u32 found_upper,
+ u32 event, u32 port, u32 node,
+ u32 scope, int must);
int tipc_topsrv_start(struct net *net);
void tipc_topsrv_stop(struct net *net);
-void tipc_subscrp_put(struct tipc_subscription *subscription);
-void tipc_subscrp_get(struct tipc_subscription *subscription);
+void tipc_sub_put(struct tipc_subscription *subscription);
+void tipc_sub_get(struct tipc_subscription *subscription);
#define TIPC_FILTER_MASK (TIPC_SUB_PORTS | TIPC_SUB_SERVICE | TIPC_SUB_CANCEL)
@@ -51,7 +51,7 @@ struct tipc_conn;
* @timer: timer governing subscription duration (optional)
* @nameseq_list: adjacent subscriptions in name sequence's subscription list
- * @subscrp_list: adjacent subscriptions in subscriber's subscription list
+ * @sub_list: adjacent subscriptions in subscriber's subscription list
* @evt: template for events generated by subscription
*/